<?php

namespace Hrm\Available\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Available\Models\Available;

class AvailablePolicy
{

    /**
     * Determine if the given user can view the available.
     *
     * @param UserPolicy $user
     * @param Available $available
     *
     * @return bool
     */
    public function view(UserPolicy $user, Available $available)
    {
        if ($user->canDo('available.available.view') && $user->isAdmin()) {
            return true;
        }

        return $available->user_id == user_id() && $available->user_type == user_type();
    }

    /**
     * Determine if the given user can create a available.
     *
     * @param UserPolicy $user
     * @param Available $available
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('available.available.create');
    }

    /**
     * Determine if the given user can update the given available.
     *
     * @param UserPolicy $user
     * @param Available $available
     *
     * @return bool
     */
    public function update(UserPolicy $user, Available $available)
    {
        if ($user->canDo('available.available.edit') && $user->isAdmin()) {
            return true;
        }

        return $available->user_id == user_id() && $available->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given available.
     *
     * @param UserPolicy $user
     * @param Available $available
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Available $available)
    {
        return $available->user_id == user_id() && $available->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given available.
     *
     * @param UserPolicy $user
     * @param Available $available
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Available $available)
    {
        if ($user->canDo('available.available.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given available.
     *
     * @param UserPolicy $user
     * @param Available $available
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Available $available)
    {
        if ($user->canDo('available.available.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
